
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class OrderRefundModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(OrderRefundModel, self).__init__(OrderRefund, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class OrderRefund:

    def __init__(self):
        super(OrderRefund, self).__init__()
        self.id = 0  # 
        self.shop_id = 0  # 店铺id
        self.order_id = ""  # 订单号
        self.refund_order_id = ""  # 退款订单号
        self.refund_type = 0  # 退款类型 0 退货退款 1 仅退款
        self.goods_refund_price = 0  # 商品退款金额
        self.real_refund_price = 0  # 实际退款金额
        self.postage = 0  # 运费
        self.reason = ""  # 退款理由
        self.status = 0  # 状态 0 提交申请 1 通过 2 拒绝 3 商品寄回中 4 撤销 5 完成 6 失败
        self.refund_status = ""  # 微信退款平台状态
        self.refund_pay_id = ""  # 支付平台退款单号
        self.address_info = ""  # 售后地址
        self.logistics_company = ""  # 物流公司
        self.logistics_number = ""  # 退货物流单号
        self.add_time = 0  # 申请时间
        self.pass_time = 0  # 审核时间
        self.logistics_time = 0  # 用户发货时间
        self.receive_time = 0  # 商家收货时间
        self.finish_time = 0  # 结束时间
        self.user_code = ""  # 添加人id
        self.manage_user = ""  # 管理人id
        self.pass_remark = ""  # 审核备注
        self.fail_remark = ""  # 订单失败备注

    @classmethod
    def get_field_list(self):
        return ['id', 'shop_id', 'order_id', 'refund_order_id', 'refund_type', 'goods_refund_price', 'real_refund_price', 'postage', 'reason', 'status', 'refund_status', 'refund_pay_id', 'address_info', 'logistics_company', 'logistics_number', 'add_time', 'pass_time', 'logistics_time', 'receive_time', 'finish_time', 'user_code', 'manage_user', 'pass_remark', 'fail_remark']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "order_refund_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2023-09-20 15:25:22
:LastEditTime: 2024-06-07 13:50:42
:LastEditors: KangWenBin
:Description: 
"""
from seven_framework.web_tornado.base_handler.base_api_handler import *
from seven_shop_studio.handlers.seven_base import SevenBaseHandler
from seven_shop_studio.models.db_models.goods.goods_model_ex import *
from seven_shop_studio.models.db_models.goods.goods_sku_model_ex import *
from seven_shop_studio.models.db_models.shop.shop_series_model_ex import *
from seven_shop_studio.models.db_models.inventory.inventory_model_ex import *
from seven_shop_studio.models.db_models.inventory.inventory_change_model import *
from seven_shop_studio.models.db_models.goods.goods_recommend_model import *
from decimal import Decimal


class GoodsListHandler(SevenBaseHandler):
    @filter_check_params(["shop_id"])
    def get_async(self):
        """
        :description: 商品管理页
        :last_editors: Kangwenbin
        """        
        page_index = int(self.request_params.get("page_index",0))
        page_size = int(self.request_params.get("page_size",10))
        sel_series_id = self.request_params.get("sel_series_id", None)
        sel_goods_name = self.request_params.get("sel_category_name", None)
        sel_begin_time = self.request_params.get("sel_begin_time", None)
        sel_end_time = self.request_params.get("sel_end_time", None)
        sel_status = self.request_params.get("sel_status", None)
        order_field = self.request_params.get("order_field", None)
        order_by = self.request_params.get("order_by", "desc")
        shop_id = self.request_params["shop_id"]
        
        condition = "a.status > -1 and a.shop_id = %s"
        param_list = [shop_id]

        if sel_status:
            condition += " and a.status = %s"
            param_list.append(sel_status)

        if sel_goods_name:
            condition += " and a.goods_short_name like %s"
            param_list.append(f"%{sel_goods_name}%")

        if sel_series_id:
            condition += " and a.series_id = %s"
            param_list.append(sel_series_id)

        if sel_begin_time:
            condition += " and a.add_time >= %s"
            param_list.append(sel_series_id)

        if sel_end_time:
            condition += " and a.add_time <= %s"
            param_list.append(sel_end_time)

        if not order_field:
            order_field = "a.sort"
        else:
            order_field = f"a.{order_field}"

        goods_list,goods_count = GoodsModelEx().get_goods_list(page_index,page_size,condition,f"{order_field} {order_by}",param_list)
        if goods_list:  
            sku_conn = GoodsSkuModelEx()      
            for item in goods_list:
                # 商品主图
                try:
                    item["goods_picture"] = json.loads(item["goods_picture"])[0]
                except:
                    item["goods_picture"] = ""
                item["inventory"] = int(item["inventory"])
                # 获取sku信息
                item["sku_list"] = sku_conn.get_goods_sku_list(item["id"])


        ret_data = {
            "model_list": goods_list,
            "count": goods_count,
            "series_list": ShopSeriesModelEx().get_dict_list(where="status = 1 and shop_id = %s",params=shop_id,field="id,series_name")
        }

        return self.reponse_json_success(ret_data)
    

class GoodsInfoHandler(SevenBaseHandler):
    @filter_check_params(["goods_id","shop_id"])
    def get_async(self):
        """
        :description: 获取商品详情
        :last_editors: KangWenBin
        """        
        goods_id = self.request_params["goods_id"]
        shop_id = self.request_params["shop_id"]

        goods_model = GoodsModel().get_dict(where="id = %s and shop_id = %s",params=[goods_id,shop_id],field="id,series_id,goods_main_images,goods_detail_images,goods_long_name,goods_short_name,goods_remark,goods_parameter,goods_service,original_price,price,goods_code,sort,status")
        if not goods_model or goods_model["status"] == -1:
            return self.reponse_json_error("获取商品信息失败")
        
        # json数据处理
        fields_to_process = ["goods_main_images", "goods_detail_images", "goods_parameter", "goods_service"]
        for field in fields_to_process:
            goods_model[field] = self.load_json_or_empty(goods_model.get(field, '[]'))
        
        # 获取sku信息
        goods_model["sku_info"] = GoodsSkuModelEx().get_goods_sku_info(goods_id)
        if not goods_model["sku_info"]["sku_list"]:
            # 获取主商品库存
            goods_model["inventory"] = InventoryModelEx().get_inventory(goods_id,0)
        else:
            goods_model["inventory"] = 0
        
        ret_data = {
            "goods_model": goods_model,
            "series_list": ShopSeriesModelEx().get_dict_list(where="status = 1 and shop_id = %s",params=shop_id,field="id,series_name")
        }
        self.reponse_json_success(ret_data)
    
    
    @filter_check_params(["goods_info","shop_id"])
    def post_async(self):
        """
        :description: 商品修改保存
        :last_editors: KangWenBin
        """        
        goods_info = self.request_params["goods_info"]
        shop_id = self.request_params["shop_id"]
        sku_list = self.request_params.get("sku_list",None)

        goods_conn = GoodsModel()
        sku_conn = GoodsSkuModel()
        
        # 参数验证
        goods_check_list = ["series_id","goods_main_images","goods_detail_images","goods_long_name",
                      "goods_short_name","goods_remark","goods_parameter","goods_service","sort"]
        if not self.param_check(goods_info, goods_check_list):
            return self.reponse_json_error("商品表单未填写完整")
        
        # 商品赋值
        goods_entity = self.dict_to_entity(Goods(), goods_info) 

        # sku
        sku_entity_list = []
        if sku_list:
            sku_check_list = ["sku_name","sku_info","price","goods_code","inventory","sku_picture"]
            for item in sku_list:
                if not self.param_check(item, sku_check_list):
                    return self.reponse_json_error("sku表单未填写完整")
                sku_entity = self.dict_to_entity(GoodsSku(),item)
                setattr(sku_entity,"inventory",item["inventory"])
                sku_entity_list.append(sku_entity)
        
        if goods_entity.id > 0:
            # 修改
            old_goods_model = goods_conn.get_entity_by_id(goods_entity.id)
            # old_sku_list = sku_conn.get_list(where="goods_id = %s",params=goods_entity.id)
            if old_goods_model.status == 1:
                return self.reponse_json_error("商品已上架，无法修改")
            
            goods_entity.goods_sold = old_goods_model.goods_sold
            goods_entity.add_time = old_goods_model.add_time
            goods_entity.shop_id = old_goods_model.shop_id

            # 验证是否有sku
            if sku_entity_list:
                min_sku_entity = min(sku_entity_list, key=lambda x: x.price)
                goods_entity.original_price = min_sku_entity.original_price
                goods_entity.price = min_sku_entity.price
                goods_entity.goods_code = ""
            
            if Decimal(goods_entity.price) <= 0:
                return self.reponse_json_error("价格错误")
            
            goods_entity.goods_main_images = JsonHelper.json_dumps(goods_entity.goods_main_images)
            goods_entity.goods_detail_images = JsonHelper.json_dumps(goods_entity.goods_detail_images)
            goods_entity.goods_parameter = JsonHelper.json_dumps(goods_entity.goods_parameter)
            goods_entity.goods_service = JsonHelper.json_dumps(goods_entity.goods_service)
            goods_conn.update_entity(goods_entity)

            if not sku_entity_list:
                # 修改商品库存
                inventory_result = self.edit_inventory(goods_entity.id,0,goods_info["inventory"],self.request_user_id(),"系统库存修改")
                if inventory_result:
                    return self.reponse_json_success(desc="提交成功")
                else:
                    return self.reponse_json_error("提交失败")
            
            # 判断sku_id是否都为0
            new_sku_entity = [x for x in sku_entity_list if x.id == 0]
            if new_sku_entity:
                # 新增
                sku_conn.update_table("status = -1","goods_id = %s",goods_entity.id)
                add_result = True
                for item in sku_entity_list:
                    item.goods_id = goods_entity.id
                    item.add_time = TimeHelper.get_now_timestamp()
                    item.sku_info = JsonHelper.json_dumps(item.sku_info)
                    item.status = 1
                    sku_result = sku_conn.add_entity(item)
                    if sku_result:
                        sku_inventory_result = self.edit_inventory(goods_entity.id,sku_result,item.inventory,self.request_user_id())
                        add_result = sku_inventory_result if add_result==True else add_result
                if add_result:
                    return self.reponse_json_success(desc="提交成功")
            else:
                # 循环修改
                for item in sku_entity_list:
                    old_sku_model = sku_conn.get_entity_by_id(item.id)
                    if old_sku_model:
                        item.add_time = old_sku_model.add_time
                        item.goods_id = old_sku_model.goods_id
                        item.sku_info = JsonHelper.json_dumps(item.sku_info)
                        item.status = 1
                        sku_conn.update_entity(item)
                        # 修改库存
                        sku_inventory_result = self.edit_inventory(goods_entity.id,item.id,item.inventory,self.request_user_id())
                return self.reponse_json_success(desc="提交成功")
            
        else:
            # 新增(需验证sku信息是否存在)
            goods_entity.add_time = TimeHelper.get_now_timestamp()
            goods_entity.shop_id = shop_id
            if sku_entity_list:
                # 获取最小的价格sku
                min_sku_entity = min(sku_entity_list, key=lambda x: x.price)
                goods_entity.original_price = min_sku_entity.original_price
                goods_entity.price = min_sku_entity.price
                goods_entity.goods_code = ""
            if Decimal(goods_entity.price) <= 0:
                return self.reponse_json_error("价格错误")
            
            goods_entity.goods_main_images = JsonHelper.json_dumps(goods_entity.goods_main_images)
            goods_entity.goods_detail_images = JsonHelper.json_dumps(goods_entity.goods_detail_images)
            goods_entity.goods_parameter = JsonHelper.json_dumps(goods_entity.goods_parameter)
            goods_entity.goods_service = JsonHelper.json_dumps(goods_entity.goods_service)
            
            goods_result = goods_conn.add_entity(goods_entity)
            if goods_result:

                # 添加sku信息
                if sku_entity_list:
                    add_result = True
                    for item in sku_entity_list:
                        item.goods_id = goods_result
                        item.add_time = TimeHelper.get_now_timestamp()
                        item.sku_info = JsonHelper.json_dumps(item.sku_info)
                        item.status = 1
                        sku_result = sku_conn.add_entity(item)
                        if sku_result:
                            sku_inventory_result = self.edit_inventory(goods_result,sku_result,item.inventory,self.request_user_id())
                            add_result = sku_inventory_result if add_result==True else add_result
                    if add_result:
                        return self.reponse_json_success(desc="提交成功")
                        
                else:
                    # 添加商品库存信息
                    if self.edit_inventory(goods_result,0,goods_info["inventory"],self.request_user_id()):
                        return self.reponse_json_success(desc="提交成功")

                        
                
        self.reponse_json_error("提交失败")

    def edit_inventory(self,goods_id,sku_id,inventory_number,user_code,remark = "初始化添加"):
        """
        :description: 修改商品库存
        :last_editors: KangWenBin
        """
        db_transaction = DbTransaction(db_config_dict=config.get_value("db_shopping_center"))
        tran_inventory_conn = InventoryModel(db_transaction=db_transaction)
        tran_inventory_change_conn = InventoryChangeModel(db_transaction=db_transaction)
        
        # 获取旧库存信息
        old_inventory = tran_inventory_conn.get_dict(where="goods_id = %s and sku_id = %s",params=[goods_id,sku_id],field="inventory")
        if old_inventory:
            # 修改库存信息
            inventory_number = int(inventory_number) - old_inventory["inventory"]
            if inventory_number == 0:
                return True
            
            tran_inventory_conn.update_table("inventory = inventory + %s","goods_id = %s and sku_id = %s",[inventory_number,goods_id,sku_id])

        else:
            # 添加商品库存信息
            db_transaction.begin_transaction()
            # 库存
            inventory = Inventory()
            inventory.goods_id = goods_id
            inventory.sku_id = sku_id
            inventory.inventory = inventory_number
            tran_inventory_conn.add_entity(inventory)

        # 库存变更记录
        inventory_change = InventoryChange()
        inventory_change.goods_id = goods_id
        inventory_change.sku_id = sku_id
        inventory_change.change_inventory = inventory_number
        inventory_change.add_time = TimeHelper.get_now_timestamp()
        inventory_change.add_user = user_code
        inventory_change.remark = remark
        tran_inventory_change_conn.add_entity(inventory_change)
        if db_transaction.commit_transaction():
            # 库存数量验证
            InventoryModelEx().check_goods_inventory(goods_id,sku_id)
            return True
        
        return False


    @filter_check_params(["goods_list","status","shop_id"])
    def put_async(self, *args, **kwargs):
        """
        :description: 商品上下架
        :last_editors: rigger
        """
        goods_list = self.request_params["goods_list"]
        status = self.request_params["status"]
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        if GoodsModel().update_table("status = %s","id in %s and shop_id = %s",[status,goods_list,shop_id]):
            return self.reponse_json_success("提交成功")
        
        self.reponse_json_error("提交失败")


    @filter_check_params(["goods_list","shop_id"])
    def delete_async(self, *args, **kwargs):
        """
        :description: 商品删除
        :last_editors: rigger
        """
        # 分类id 
        goods_list = self.request_params["goods_list"]
        shop_id = self.request_params["shop_id"]

        good_model_list = GoodsModel().get_dict_list(where="id in %s and shop_id = %s",params=[goods_list,shop_id],field="status")
        if good_model_list:
            status = sum([x["status"] for x in good_model_list])
            if status > 0:
                return self.reponse_json_error("请确认商品已下架后再删除")
        
        # TODO 执行业务
        GoodsModel().update_table("status = -1","id in %s and shop_id = %s",[goods_list,shop_id])
        
        self.reponse_json_error("提交失败")


class GoodsRecommendListHandler(SevenBaseHandler):
    @filter_check_params(["shop_id"])
    def get_async(self):
        """
        :description: 推荐商品列表
        :last_editors: KangWenBin
        """        
        page_index = int(self.request_params.get("page_index",0))
        page_size = int(self.request_params.get("page_size",10))
        sel_series_id = self.request_params.get("sel_series_id", None)
        sel_goods_name = self.request_params.get("sel_category_name", None)
        sel_begin_time = self.request_params.get("sel_begin_time", None)
        sel_end_time = self.request_params.get("sel_end_time", None)
        sel_status = self.request_params.get("sel_status", None)
        order_field = self.request_params.get("order_field", None)
        order_by = self.request_params.get("order_by", "desc")
        shop_id = self.request_params["shop_id"]
        
        condition = "b.status > -1 and b.shop_id = %s"
        param_list = [shop_id]

        if sel_status:
            condition += " and b.status = %s"
            param_list.append(sel_status)

        if sel_goods_name:
            condition += " and b.goods_long_name like %s"
            param_list.append(f"%{sel_goods_name}%")

        if sel_series_id:
            condition += " and b.series_id = %s"
            param_list.append(sel_series_id)

        if sel_begin_time:
            condition += " and a.add_time >= %s"
            param_list.append(sel_series_id)

        if sel_end_time:
            condition += " and a.add_time <= %s"
            param_list.append(sel_end_time)

        if not order_field:
            order_field = "a.sort"
        else:
            order_field = f"a.{order_field}"

        goods_list,goods_count = GoodsModelEx().get_goods_recommend_list(page_index,page_size,condition,f"{order_field} {order_by}",param_list)
        if goods_list:  
            sku_conn = GoodsSkuModelEx()      
            for item in goods_list:
                # 商品主图
                try:
                    item["goods_picture"] = json.loads(item["goods_picture"])[0]
                except:
                    item["goods_picture"] = ""
                # 获取sku信息
                item["sku_list"] = sku_conn.get_goods_sku_list(item["goods_id"])


        ret_data = {
            "model_list": goods_list,
            "count": goods_count,
            "series_list": ShopSeriesModelEx().get_dict_list(where="status = 1 and shop_id = %s",params=shop_id,field="id,series_name")
        }

        return self.reponse_json_success(ret_data)
    
    @filter_check_params(["shop_id","goods_id_list"])
    def post_async(self):
        """
        :description: 导入商品
        :last_editors: KangWenBin
        """
        shop_id = self.request_params["shop_id"]
        goods_id_list = self.request_params["goods_id_list"]

        # 判断商品是否已经存在
        goods_list = GoodsModelEx().get_dict_list(where="status > -1 and shop_id = %s and id in %s",params=[shop_id,goods_id_list],field="id")
        if goods_list:
            conn = GoodsRecommendModel()
            for item in goods_list:
                recommend_entity = GoodsRecommend()
                recommend_entity.goods_id = item["id"]
                recommend_entity.sort = 0
                recommend_entity.add_time = TimeHelper.get_now_timestamp()
                conn.add_entity(recommend_entity)
            return self.reponse_json_success(desc="提交成功")
        else:
            return self.reponse_json_error("无法获取商品列表")
        
    @filter_check_params(["goods_id","sort"])
    def put_async(self):
        """
        :description: 修改推荐商品排序
        :last_editors: KangWenBin
        """
        goods_id = self.request_params["goods_id"]
        sort = self.request_params["sort"]

        GoodsRecommendModel().update_table("sort = %s","goods_id = %s",[sort,goods_id])
        return self.reponse_json_success(desc="提交成功")
    
    @filter_check_params(["goods_id"])
    def delete_async(self):
        """
        :description: 删除推荐商品
        :last_editors: KangWenBin
        """
        goods_id = self.request_params["goods_id"]

        if GoodsRecommendModel().del_entity(where="goods_id = %s",params=[goods_id]):
            return self.reponse_json_success(desc="提交成功")
        
        self.reponse_json_error("提交失败")

        
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class CouponModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(CouponModel, self).__init__(Coupon, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class Coupon:

    def __init__(self):
        super(Coupon, self).__init__()
        self.id = 0  # 
        self.shop_id = 0  # 店铺id
        self.coupon_name = ""  # 优惠券名称
        self.coupon_type = 0  # 优惠券类型 0 满减券 1 折扣券
        self.use_price = 0  # 使用条件金额
        self.coupon_price = 0  # 优惠金额
        self.coupon_discount = 0  # 优惠折扣
        self.goods_limit = 0  # 使用限制 0 关闭 1 开启
        self.coupon_inventory = 0  # 优惠券数量
        self.record_number = 0  # 领取数量
        self.begin_time = 0  # 有效期_开始时间
        self.end_time = 0  # 有效期_结束时间
        self.using_rule = ""  # 使用规则
        self.add_time = 0  # 添加时间
        self.is_receive = 0  # 是否可以领取 0 否 1 是
        self.status = 0  # 优惠券状态 0 未发布 1 已发布 -1 伪删除

    @classmethod
    def get_field_list(self):
        return ['id', 'shop_id', 'coupon_name', 'coupon_type', 'use_price', 'coupon_price', 'coupon_discount', 'goods_limit', 'coupon_inventory', 'record_number', 'begin_time', 'end_time', 'using_rule', 'add_time', 'is_receive', 'status']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "coupon_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-05-16 13:39:35
:LastEditTime: 2024-06-05 14:37:28
:LastEditors: KangWenBin
:Description: 
"""
from seven_framework.web_tornado.base_handler.base_api_handler import *
from seven_shop_studio.handlers.seven_base import SevenBaseHandler
from seven_shop_studio.models.db_models.shop.shop_category_model import *
from seven_shop_studio.models.db_models.shop.shop_series_model_ex import *
from seven_shop_studio.models.db_models.shop.shop_category_series_model import *
from seven_shop_studio.models.db_models.goods.goods_model import *



class SeriesListHandler(SevenBaseHandler):
    @filter_check_params(["shop_id"])
    def get_async(self, *args, **kwargs):
        """
        :description: 系列列表
        :last_editors: KangWenBin
        """        
        page_index = int(self.request_params.get("page_index",0))
        page_size = int(self.request_params.get("page_size",10))
        sel_series_name = self.request_params.get("sel_series_name", None)
        sel_category_id = self.request_params.get("sel_category_id", None)
        sel_status = self.request_params.get("sel_status", None)
        shop_id = self.request_params["shop_id"]
        
        condition = "status > -1 and shop_id = %s"
        param_list = [shop_id]

        if sel_status:
            condition += " and status = %s"
            param_list.append(sel_status)

        if sel_series_name:
            condition += " and series_name like %s"
            param_list.append(f"%{sel_series_name}%")

        if sel_category_id:
            category_series_list = ShopCategorySeriesModel().get_dict_list(where="category_id = %s",params=sel_category_id,field="series_id")
            if category_series_list:
                condition += " and id in %s"
                param_list.append([x["series_id"] for x in category_series_list])
            else:
                condition += " and 1=2"

        
        series_conn = ShopSeriesModelEx()
        goods_conn = GoodsModel()
        series_list,series_count = series_conn.get_dict_page_list(field="id,sort,series_name,series_picture,series_poster,add_time,status", page_index=page_index,page_size=page_size,order_by="sort desc",where=condition,params=param_list)
        if series_list:
            for item in series_list:
                item["category_name"] = ",".join([x["category_name"] for x in series_conn.get_series_category_list(item["id"])])
                item["goods_count"] = goods_conn.get_total(where="series_id = %s",params=item["id"])

        ret_data = {
            "model_list": series_list,
            "count": series_count,
            "category_list": ShopCategoryModel().get_dict_list(where="status >-1 and shop_id = %s",params=shop_id,field="id,category_name",order_by="sort desc")
        }

        return self.reponse_json_success(ret_data)
    


class SeriesInfoHandler(SevenBaseHandler):
    @filter_check_params(["series_id","shop_id"])
    def get_async(self):
        """
        :description: 获取系列信息
        :last_editors: KangWenBin
        """        
        series_id = self.request_params["series_id"]
        shop_id = self.request_params["shop_id"]

        series_model = ShopSeriesModel().get_dict(where="id = %s and shop_id = %s",params=[series_id,shop_id])
        if not series_model:
            return self.reponse_json_error("获取系列信息失败")
        series_model["all_category_list"] = ShopCategoryModel().get_dict_list(where="status >-1 and shop_id = %s",params=shop_id,field="id,category_name",order_by="sort desc")
        series_model["category_list"] = ShopSeriesModelEx().get_series_category_list(series_id)
        self.reponse_json_success(series_model)

    @filter_check_params(["series_id","series_name","series_picture","sort","shop_id"])
    def post_async(self, *args, **kwargs):
        """
        :description: 系列保存
        :last_editors: rigger
        """
        # 分类id(新增给0) 
        series_id = self.request_params["series_id"]
        series_name = self.request_params["series_name"]
        series_picture = self.request_params["series_picture"]
        series_poster = self.request_params.get("series_poster","")
        sort = self.request_params["sort"]
        category_list = self.request_params.get("category_list",[])
        shop_id = self.request_params["shop_id"]

        if not category_list:
            return self.reponse_json_error("请选择分类信息")
        
        # TODO 执行业务
        series_conn = ShopSeriesModel()
        category_series_conn = ShopCategorySeriesModel()

        if series_id == 0:
            # 新增
            series_entity = ShopSeries()
            series_entity.shop_id = shop_id
            series_entity.series_name = series_name
            series_entity.series_picture = series_picture
            series_entity.series_poster = series_poster
            series_entity.sort = sort
            series_entity.status = 0
            series_entity.add_time = TimeHelper.get_now_timestamp()
            ret = series_conn.add_entity(series_entity)
            if ret:
                for item in category_list:
                    # 新增关联
                    category_series_entity = ShopCategorySeries()
                    category_series_entity.category_id = item
                    category_series_entity.series_id = ret
                    category_series_conn.add_entity(category_series_entity)
            
                return self.reponse_json_success(desc = "提交成功")
            
        else:
            series_model = series_conn.get_entity_by_id(series_id)
            if not series_model:
                return self.reponse_json_error("无法获取系列信息")
            
            if series_model.status == 1:
                return self.reponse_json_error("系列已上架，无法修改")
            
            series_model.series_name = series_name
            series_model.series_picture = series_picture
            series_model.series_poster = series_poster
            series_model.sort = sort

            series_conn.update_entity(series_model)
            # 修改分类关联
            category_series_conn.del_entity(where="series_id = %s",params = series_id)
            for item in category_list:
                # 新增关联
                category_series_entity = ShopCategorySeries()
                category_series_entity.category_id = item
                category_series_entity.series_id = series_id
                category_series_conn.add_entity(category_series_entity)
            return self.reponse_json_success(desc="提交成功")
        
        self.reponse_json_error("提交失败")
        

    @filter_check_params(["series_id","shop_id"])
    def put_async(self, *args, **kwargs):
        """
        :description: 系列上下架
        :last_editors: rigger
        """
        # 分类id 
        series_id = self.request_params["series_id"]
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        conn = ShopSeriesModel()
        series_model = conn.get_dict(where="id = %s and shop_id = %s",params=[series_id,shop_id],field="status")
        if not series_model or series_model["status"] == -1:
            return self.reponse_json_error("无法获取系列信息")

        status = 0
        if series_model["status"] == 0:
            status = 1

        if conn.update_table("status = %s","id = %s",[status,series_id]):
            return self.reponse_json_success(desc="提交成功")
        
        self.reponse_json_error("提交失败")
        

    @filter_check_params(["series_id","shop_id"])
    def delete_async(self, *args, **kwargs):
        """
        :description: 系列删除
        :last_editors: rigger
        """
        # 分类id 
        series_id = self.request_params["series_id"]
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        conn = ShopSeriesModel()
        series_model = conn.get_dict(where="id = %s and shop_id = %s",params=[series_id,shop_id],field="status")
        if not series_model or series_model["status"] == -1:
            return self.reponse_json_error("无法获取系列信息")
        
        if series_model["status"] == 1:
            return self.reponse_json_error("系列已上架，无法删除")

        if conn.update_table("status = -1","id = %s",series_id):
            return self.reponse_json_success(desc = "提交成功")
        
        self.reponse_json_error("提交失败")





#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class GoodsModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(GoodsModel, self).__init__(Goods, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class Goods:

    def __init__(self):
        super(Goods, self).__init__()
        self.id = 0  # 
        self.shop_id = 0  # 店铺id
        self.series_id = 0  # 系列id
        self.goods_main_images = ""  # 商品主图(多张)
        self.goods_detail_images = ""  # 商品详情图(多张)
        self.goods_long_name = ""  # 商品长名称
        self.goods_short_name = ""  # 商品短名称
        self.goods_remark = ""  # 商品备注
        self.goods_parameter = ""  # 商品参数
        self.goods_service = ""  # 商品服务条款
        self.goods_sold = 0  # 商品销量
        self.original_price = 0  # 原价
        self.price = 0  # 价格
        self.integral = 0  # 积分
        self.goods_code = ""  # 商家编码
        self.is_integral = 0  # 是否积分商品 0 否 1 是
        self.sort = 0  # 商品排序
        self.status = 0  # 状态 0 未上架 1 已上架 -1 伪删除
        self.add_time = 0  # 添加时间

    @classmethod
    def get_field_list(self):
        return ['id', 'shop_id', 'series_id', 'goods_main_images', 'goods_detail_images', 'goods_long_name', 'goods_short_name', 'goods_remark', 'goods_parameter', 'goods_service', 'goods_sold', 'original_price', 'price', 'integral', 'goods_code', 'is_integral', 'sort', 'status', 'add_time']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "goods_tb"
    



"""
:Author: KangWenBin
:Date: 2024-05-17 15:57:20
:LastEditTime: 2024-05-17 17:29:38
:LastEditors: KangWenBin
:Description: 
"""
from seven_shop_studio.models.db_models.goods.goods_sku_model import *


class GoodsSkuModelEx(GoodsSkuModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)

    def get_goods_sku_list(self,goods_id):
        """
        :description: 获取商品sku信息
        :last_editors: KangWenBin
        """
        sql = "SELECT a.id,a.goods_code,a.sku_picture,a.sku_name,a.price,b.inventory FROM goods_sku_tb a JOIN inventory_tb b ON a.goods_id = b.goods_id AND a.id = b.sku_id WHERE a.status > -1 and a.goods_id = %s"
        return self.db.fetch_all_rows(sql,goods_id)

    def get_goods_sku_info(self, goods_id):
        """
        :description: 获取商品sku信息
        :param goods_id 商品id
        :last_editors: Kangwenbin
        """        
        ret_model = {
            "sku_list": [],
            "sku_model": {}
        }
        sql = "SELECT a.*,b.inventory FROM goods_sku_tb a JOIN inventory_tb b ON a.goods_id = b.goods_id AND a.id = b.sku_id WHERE a.status > -1 AND a.goods_id = %s"
        goods_sku_list= self.db.fetch_all_rows(sql,goods_id)
        if goods_sku_list:
            # sku信息处理
            for item in goods_sku_list:
                # 不存在sku细项则跳过
                if not item["sku_info"]:
                    continue

                json_sku_list = json.loads(item["sku_info"])
                # 选择项处理
                for sku in json_sku_list:
                    if sku["model_name"] not in ret_model["sku_model"]:
                        ret_model["sku_model"][sku["model_name"]] = []

                    if sku["model_value"] not in ret_model["sku_model"][sku["model_name"]]:
                        ret_model["sku_model"][sku["model_name"]].append(sku["model_value"])

                sku_model = {
                    "sku_name": item["sku_name"],
                    "id": item["id"],
                    "price": item["price"],
                    "original_price":item["original_price"],
                    "integral":item["integral"],
                    "sku_picture": item["sku_picture"],
                    "goods_code": item["goods_code"],
                    "inventory": item["inventory"]
                }
                ret_model["sku_list"].append(sku_model)
                
        return ret_model



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class OrderModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(OrderModel, self).__init__(Order, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class Order:

    def __init__(self):
        super(Order, self).__init__()
        self.id = 0  # 
        self.shop_id = 0  # 店铺id
        self.order_id = ""  # 订单号
        self.pay_channel = 0  # 支付渠道 0 微信小程序
        self.channel_id = 0  # 订单来源 1 商品页 2 购物车
        self.pay_order_id = ""  # 支付平台订单id
        self.user_code = ""  # 购买用户id
        self.open_id = ""  # open_id
        self.province_name = ""  # 省
        self.city_name = ""  # 市
        self.district_name = ""  # 县、区
        self.consignee = ""  # 收货人
        self.phone = ""  # 电话
        self.address_info = ""  # 详细地址
        self.buy_count = 0  # 订单购买总数量
        self.price = 0  # 订单商品总价
        self.real_pay_price = 0  # 实际支付价格
        self.postage = 0  # 运费
        self.coupon_id = 0  # 优惠券id
        self.coupon_price = 0  # 优惠金额
        self.add_time = 0  # 下单时间
        self.pay_time = 0  # 支付时间
        self.status = 0  # 状态 0 未支付 1 已取消 2 已支付(待发货) 3 已发货 4 已完成 5 不予发货
        self.logistics_company = ""  # 物流公司
        self.logistics_number = ""  # 物流单号
        self.logistics_time = 0  # 发货时间
        self.finish_time = 0  # 完成时间
        self.remark = ""  # 买家备注
        self.shop_remark = ""  # 卖家备注
        self.cancel_remark = ""  # 取消备注
        self.is_refund = 0  # 是否退款 0 否 1 是

    @classmethod
    def get_field_list(self):
        return ['id', 'shop_id', 'order_id', 'pay_channel', 'channel_id', 'pay_order_id', 'user_code', 'open_id', 'province_name', 'city_name', 'district_name', 'consignee', 'phone', 'address_info', 'buy_count', 'price', 'real_pay_price', 'postage', 'coupon_id', 'coupon_price', 'add_time', 'pay_time', 'status', 'logistics_company', 'logistics_number', 'logistics_time', 'finish_time', 'remark', 'shop_remark', 'cancel_remark', 'is_refund']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "order_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ShopModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(ShopModel, self).__init__(Shop, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class Shop:

    def __init__(self):
        super(Shop, self).__init__()
        self.id = 0  # 
        self.wait_pay_time = 0  # 待付款订单自动取消时间(分钟)
        self.logistics_time = 0  # 订单发货截止时间(天) 0 不限制 
        self.auto_receipt_time = 0  # 发货后自动确认时间(天) 0 不操作
        self.consignee = ""  # 收件人
        self.phone = ""  # 电话
        self.address_info = ""  # 退货地址
        self.refund_time = 0  # 退货有效期(超过特定时间未填写退货单号，则自动取消退货申请)
        self.refund_audit = 0  # 退款预计审核时间(小时)
        self.postage_type = 0  # 邮费类型 0 统一配置 1 指定配送区域不包邮
        self.postage = 0  # 邮费
        self.shipping_method = ""  # 配送方式
        self.remark = ""  # 备注说明
        self.coupon_remark = ""  # 优惠券使用说明
        self.status = 0  # 店铺状态 0 下架 1 正常

    @classmethod
    def get_field_list(self):
        return ['id', 'wait_pay_time', 'logistics_time', 'auto_receipt_time', 'consignee', 'phone', 'address_info', 'refund_time', 'refund_audit', 'postage_type', 'postage', 'shipping_method', 'remark', 'coupon_remark', 'status']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "shop_tb"
    



# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-05-07 11:37:05
:LastEditTime: 2024-06-14 17:02:46
:LastEditors: KangWenBin
:Description: 
"""
import base64
from Crypto.PublicKey import RSA
from Crypto.Signature import PKCS1_v1_5
from Crypto.Hash import SHA256
from Crypto.Cipher import AES
from seven_framework.time import *
from seven_framework.uuid import *
from seven_framework.http import *
import seven_framework.config as config
from datetime import datetime, timezone
import random
import string
import json

class WechatPayHelper(object):
    def __init__(self) -> None:
        """
        :description: 微信支付初始化
        :last_editors: KangWenBin
        """        
        wechat_pay_config = config.get_value("wechat_pay_config",{})
        self.wechat_app_id = wechat_pay_config.get("wechat_app_id","")
        self.mch_id = wechat_pay_config.get("mch_id","")
        self.notify_url = wechat_pay_config.get("notify_url","")
        self.serial_no = wechat_pay_config.get("serial_no","")
        self.v3_key = wechat_pay_config.get("v3","")
        # 私钥
        with open(wechat_pay_config.get("private_key_path","")) as file:
            private_key = file.read()
        rsa_key = RSA.import_key(private_key)
        self.signer = PKCS1_v1_5.new(rsa_key)
        # 公钥
        with open(wechat_pay_config.get("public_key_path","")) as file:
            public_key = file.read()
        public_rsa_key = RSA.importKey(public_key)
        self.public_signer = PKCS1_v1_5.new(public_rsa_key)
        

    def wechat_jsapi_refund(self,order_id, refund_order_id, refund_price, total_price):
        """
        :description: 微信jsapi支付
        :param: order_id 商户订单号
        :param: title 标题
        :param: price 金额
        :last_editors: KangWenBin
        """        
        ret_data = {
            "result":0,
            "desc":"",
            "data":None
        }

        body = {
            "out_trade_no": order_id,
            "out_refund_no": refund_order_id,
            "notify_url": self.notify_url,
            "amount":{
                "refund": refund_price,
                "total": total_price,
                "currency": "CNY"
            }
        }

        headers = {
            "Authorization": self._create_authorization(json.dumps(body),"POST","/v3/refund/domestic/refunds"),
            "Accept": "application/json",
            "Content-Type": "application/json"
        }

        result = HTTPHelper.post("https://api.mch.weixin.qq.com/v3/refund/domestic/refunds",json = body, headers = headers)
        if result.status_code == 200:
            refund_data = json.loads(result.text)

            pay_data = {
                "refund_id": refund_data["refund_id"],
                "out_refund_no": refund_data["out_refund_no"],
                "status": refund_data["status"],
                "refund_price": refund_data["amount"]["refund"]
            }

            ret_data["result"] = 1
            ret_data["data"] = pay_data
            return ret_data
        else:
            ret_data["desc"] = result.text
            return ret_data
        
    
    def _create_authorization(self,data,method,url):
        """
        :description: 
        :param {*} data 参数内容
        :param {*} method 请求方式(大写)
        :param {*} url 请求路由
        :last_editors: KangWenBin
        """    
        timestamp = str(TimeHelper.get_now_timestamp())
        nonce_str = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(32))
        sign_list = [method, url, timestamp, nonce_str]
        if data is not None:
            sign_list.append(data)
        else:
            sign_list.append('')
        sign_str = '\n'.join(sign_list) + '\n'
        signature = self._signature_v3(sign_str)
        authorization = f'WECHATPAY2-SHA256-RSA2048 mchid="{self.mch_id}",nonce_str="{nonce_str}",signature="{signature}",timestamp="{timestamp}",serial_no="{self.serial_no}"'
        return authorization


    def _signature_v3(self, sign_str):
        """
        :description:  生成V3签名值
        :param private_key_path：私钥路径
        :param sign_str：签名字符串
        """
        try:
            digest = SHA256.new(sign_str.encode('utf-8'))
            return base64.b64encode(self.signer.sign(digest)).decode('utf-8')
        except Exception:
            raise "WeixinPaySignIError"
        

    def check_notify_sign(self, timestamp, nonce, body, response_signature):
        """
        :description: 回调验签
        :last_editors: KangWenBin
        """        

        body = body.decode("utf-8")
        sign_str = f"{timestamp}\n{nonce}\n{body}\n"
        digest = SHA256.new(sign_str.encode('UTF-8'))  # 对响应体进行RSA加密
        return self.public_signer.verify(digest, base64.b64decode(response_signature))  # 验签


    def decode_notify_data(self, ciphertext,nonce,associated_data):
        """
        :description: 微信解密
        :last_editors: KangWenBin
        """        
        cipher = AES.new(self.v3_key.encode(), AES.MODE_GCM, nonce=nonce.encode())
        cipher.update(associated_data.encode())
        en_data = base64.b64decode(ciphertext.encode('utf-8'))
        auth_tag = en_data[-16:]
        _en_data = en_data[:-16]
        plaintext = cipher.decrypt_and_verify(_en_data, auth_tag)
        return plaintext.decode()
    
    
    def iso_to_timestamp(self,iso_time):
        """Convert ISO 8601 formatted string to a timestamp."""
        dt = datetime.fromisoformat(iso_time)  # Convert string to datetime object
        utc_dt = dt.astimezone(timezone.utc)  # Adjust the datetime object to UTC
        return int(utc_dt.timestamp())









# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-06-06 14:37:56
:LastEditTime: 2024-06-18 17:03:25
:LastEditors: KangWenBin
:Description: 
"""
from seven_framework.web_tornado.base_handler.base_api_handler import *
from seven_shop_studio.handlers.seven_base import SevenBaseHandler
from seven_shop_studio.models.db_models.shop.shop_model import *
from seven_shop_studio.models.db_models.shop.shop_postage_model import *

class ShopInfoHandler(SevenBaseHandler):
    @filter_check_params(["shop_id"])
    def get_async(self):
        """
        :description: 获取店铺信息
        :last_editors: KangWenBin
        """        
        shop_id = self.request_params["shop_id"]

        shop_model = ShopModel().get_dict_by_id(shop_id)
        if not shop_model:
            return self.reponse_json_error("无法获取店铺信息")
        
        postage_list = []
        if shop_model["postage_type"] == 1:
            postage_list = ShopPostageModel().get_dict_list(where="shop_id = %s", params=[shop_id],field="province_name,postage")
        shop_model["postage_list"] = postage_list
        
        self.reponse_json_success(shop_model)


    @filter_check_params(["shop_info","shop_id"])
    def post_async(self):
        """
        :description: 店铺信息保存
        :last_editors: KangWenBin
        """
        shop_id = self.request_params["shop_id"]
        shop_info = self.request_params["shop_info"]
        postage_list = self.request_params.get("postage_list",[])

        if shop_info["postage_type"] == 1 and not postage_list:
            return self.reponse_json_error("邮费配置未填写完整")
        # 参数验证
        check_list = ["wait_pay_time","logistics_time","auto_receipt_time",
                      "consignee","phone","address_info","refund_time","refund_audit","postage_type","postage","shipping_method","remark","coupon_remark"]
        if not self.param_check(shop_info, check_list):
            return self.reponse_json_error("商品表单未填写完整")

        shop_entity = self.dict_to_entity(Shop(), shop_info) 
        if shop_id > 0:
            # 修改
            shop_entity.id = shop_id
            shop_entity.status = 1
            ShopModel().update_entity(shop_entity)    
            # 删除旧邮费配置    
            ShopPostageModel().del_entity(where="shop_id = %s",params=[shop_id])
            if shop_info["postage_type"] == 1:
                # 新增邮费配置
                for item in postage_list:
                    postage_entity = ShopPostage()
                    postage_entity.shop_id = shop_id
                    postage_entity.province_name = item["province_name"]
                    postage_entity.postage = item["postage"]
                    ShopPostageModel().add_entity(postage_entity)
            return self.reponse_json_success(desc="提交成功")
        else:
            # 新增
            shop_entity.status = 1
            result = ShopModel().add_entity(shop_entity)
            if result:
                if shop_info["postage_type"] == 1:
                    # 新增邮费配置
                    for item in postage_list:
                        postage_entity = ShopPostage()
                        postage_entity.shop_id = result
                        postage_entity.province_name = item["province_name"]
                        postage_entity.postage = item["postage"]
                        ShopPostageModel().add_entity(postage_entity)
            return self.reponse_json_success(desc="提交成功")
        



from seven_shop_studio.models.db_models.goods.goods_model import *


class GoodsModelEx(GoodsModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)

    def get_goods_list(self,page_index,page_size,where='',order_by='',params=None):
        """
        :description: 商品列表
        :last_editors: KangWenBin
        """        
        limit = f"LIMIT {str(int(page_index) * int(page_size))},{str(page_size)}"

        condition = ""
        if where:
            condition += f" and {where}"

        sql = f"SELECT a.id,a.sort,a.goods_main_images as goods_picture,a.goods_short_name,a.series_id,ifnull(d.series_name,'') as series_name,a.goods_sold,SUM(c.inventory) AS inventory,a.status,a.add_time FROM goods_tb a LEFT JOIN goods_sku_tb b ON a.id = b.goods_id LEFT JOIN inventory_tb c ON a.id = c.goods_id AND (b.id = c.sku_id OR (b.id IS NULL AND c.sku_id = 0)) left join shop_series_tb d on a.series_id = d.id  WHERE (b.status = 1 OR b.status IS NULL) {condition} GROUP BY a.id ORDER BY {order_by} {limit}"

        ret_list = self.db.fetch_all_rows(sql,params)
        sql_count = f"SELECT count(*) as count FROM goods_tb a LEFT JOIN goods_sku_tb b ON a.id = b.goods_id LEFT JOIN inventory_tb c ON a.id = c.goods_id AND (b.id = c.sku_id OR (b.id IS NULL AND c.sku_id = 0)) left join shop_series_tb d on a.series_id = d.id WHERE (b.status = 1 OR b.status IS NULL) {condition} GROUP BY a.id" 
        row = self.db.get_row_count(sql_count,params)
        return ret_list,row

    def get_goods_recommend_list(self,page_index,page_size,where='',order_by='',params=None):
        """
        :description: 推荐商品列表
        :last_editors: KangWenBin
        """
        limit = f"LIMIT {str(int(page_index) * int(page_size))},{str(page_size)}"
        condition = ""
        if where:
            condition += f" where {where}"
        if order_by:
            order_by = f" order by {order_by}"
        sql = f"SELECT a.sort,a.goods_id,b.goods_long_name,b.goods_main_images as goods_picture,b.series_id,c.series_name,b.status,a.add_time FROM goods_recommend_tb a JOIN goods_tb b ON a.goods_id = b.id JOIN shop_series_tb c ON c.id = b.series_id {condition} {order_by} {limit}"
        ret_list = self.db.fetch_all_rows(sql,params)
        sql_count = f"SELECT count(*) as count FROM goods_recommend_tb a JOIN goods_tb b ON a.goods_id = b.id JOIN shop_series_tb c ON c.id = b.series_id {condition}" 
        row = self.db.get_row_count(sql_count,params)
        return ret_list,row


# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-05-22 16:19:34
:LastEditTime: 2024-06-19 11:32:08
:LastEditors: KangWenBin
:Description: 
"""
from seven_shop_studio.models.db_models.order.order_goods_model import *

class OrderGoodsModelEx(OrderGoodsModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)


    def get_order_goods_list(self,order_id_list):
        """
        :description: 获取订单商品相关信息
        :last_editors: Kangwenbin
        """
        
        sql = "SELECT a.order_id,a.sku_name,a.goods_picture,a.goods_name,a.buy_count,a.price,a.real_pay_price,c.status as refund_status FROM order_goods_tb a LEFT JOIN order_refund_goods_tb b ON a.order_id = b.order_id AND a.goods_id = b.goods_id AND a.sku_id = b.sku_id LEFT JOIN order_refund_tb c ON b.refund_order_id = c.refund_order_id where a.order_id in %s"
        goods_list = self.db.fetch_all_rows(sql, (order_id_list,))
        return goods_list



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class CouponGrantModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(CouponGrantModel, self).__init__(CouponGrant, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class CouponGrant:

    def __init__(self):
        super(CouponGrant, self).__init__()
        self.id = 0  # 
        self.grant_name = ""  # 投放名称
        self.grant_type = ""  # 投放人群 0 新用户 1 未消费用户 2 已消费用户 3 会员用户
        self.grant_picture = ""  # 投放海报
        self.coupon_id = 0  # 消费券id
        self.begin_time = 0  # 投放开始时间
        self.end_time = 0  # 投放结束时间
        self.add_time = 0  # 创建时间
        self.status = 0  # 状态 0 未发布 1 已发布

    @classmethod
    def get_field_list(self):
        return ['id', 'grant_name', 'grant_type', 'grant_picture', 'coupon_id', 'begin_time', 'end_time', 'add_time', 'status']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "coupon_grant_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class InventoryModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(InventoryModel, self).__init__(Inventory, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class Inventory:

    def __init__(self):
        super(Inventory, self).__init__()
        self.id = 0  # 
        self.goods_id = 0  # 商品id
        self.sku_id = 0  # sku_id
        self.inventory = 0  # 库存数

    @classmethod
    def get_field_list(self):
        return ['id', 'goods_id', 'sku_id', 'inventory']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "inventory_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-05-16 13:39:35
:LastEditTime: 2024-06-05 16:12:04
:LastEditors: KangWenBin
:Description: 
"""
from seven_framework.web_tornado.base_handler.base_api_handler import *
from seven_shop_studio.handlers.seven_base import SevenBaseHandler
from seven_shop_studio.models.db_models.shop.shop_category_model import *
from seven_shop_studio.models.db_models.shop.shop_series_model_ex import *



class CategoryListHandler(SevenBaseHandler):
    @filter_check_params(["shop_id"])
    def get_async(self, *args, **kwargs):
        """
        :description: 分类列表
        :last_editors: KangWenBin
        """        
        
        shop_id = self.request_params["shop_id"]
        page_index = int(self.request_params.get("page_index",0))
        page_size = int(self.request_params.get("page_size",10))
        sel_category_name = self.request_params.get("sel_category_name", None)
        sel_status = self.request_params.get("sel_status", None)
        
        condition = "status > -1 and shop_id = %s"
        param_list = [shop_id]

        if sel_status:
            condition += " and status = %s"
            param_list.append(sel_status)

        if sel_category_name:
            condition += " and category_name like %s"
            param_list.append(f"%{sel_category_name}%")

        category_list,category_count = ShopCategoryModel().get_dict_page_list(field="id,category_name,status,add_time,sort", page_index=page_index,page_size=page_size,order_by="sort desc",where=condition,params=param_list)
        if category_list:
            series_conn = ShopSeriesModelEx()
            for item in category_list:
                item["series_count"] = series_conn.get_category_series_count(item["id"])

        ret_data = {
            "model_list": category_list,
            "count": category_count
        }

        return self.reponse_json_success(ret_data)
    


class CategoryInfoHandler(SevenBaseHandler):

    @filter_check_params(["id","category_name","sort","shop_id"])
    def post_async(self, *args, **kwargs):
        """
        :description: 分类保存
        :last_editors: rigger
        """
        # 分类id(新增给0) 
        id = self.request_params["id"]
        # 分类名称 
        category_name = self.request_params["category_name"]
        # 排序(数字大的排前面) 
        sort = self.request_params["sort"]
        # 店铺id
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        conn = ShopCategoryModel()
        if id == 0:
            # 新增
            category_entity = ShopCategory()
            category_entity.shop_id = shop_id
            category_entity.category_name = category_name
            category_entity.sort = sort
            category_entity.status = 0
            category_entity.add_time = TimeHelper.get_now_timestamp()
            ret = conn.add_entity(category_entity)
            if ret:
                return self.reponse_json_success(desc = "提交成功")
            
        else:
            category_model = conn.get_entity_by_id(id)
            if not category_model:
                return self.reponse_json_error("无法获取分类信息")

            if category_model.status == 1:
                return self.reponse_json_error("分类已发布，无法修改")

            category_model.category_name = category_name
            category_model.sort = sort

            if conn.update_entity(category_model):
                return self.reponse_json_success(desc="提交成功")
        
        self.reponse_json_error("提交失败")
        

    @filter_check_params(["category_id","shop_id"])
    def put_async(self, *args, **kwargs):
        """
        :description: 分类上下架
        :last_editors: rigger
        """
        # 分类id 
        category_id = self.request_params["category_id"]
        # 店铺id
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        conn = ShopCategoryModel()
        category_model = conn.get_dict(where="id = %s and shop_id = %s",params=[category_id,shop_id],field="status")
        if not category_model or category_model["status"] == -1:
            return self.reponse_json_error("无法获取分类信息")

        status = 0
        if category_model["status"] == 0:
            status = 1

        if conn.update_table("status = %s","id = %s",[status,category_id]):
            return self.reponse_json_success(desc="提交成功")
        
        self.reponse_json_error("提交失败")
        

    @filter_check_params(["category_id","shop_id"])
    def delete_async(self, *args, **kwargs):
        """
        :description: 分类删除
        :last_editors: rigger
        """
        # 分类id 
        category_id = self.request_params["category_id"]
        # 店铺id
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        conn = ShopCategoryModel()
        category_model = conn.get_dict(where="id = %s and shop_id = %s",params=[category_id,shop_id],field="status")
        if not category_model or category_model["status"] == -1:
            return self.reponse_json_error("无法获取分类信息")
        
        if category_model["status"] == 1:
            return self.reponse_json_error("分类已发布，无法删除")

        if conn.update_table("status = -1","id = %s",category_id):
            return self.reponse_json_success(desc = "提交成功")
        
        self.reponse_json_error("提交失败")




# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-05-24 18:03:11
:LastEditTime: 2024-05-24 18:12:41
:LastEditors: KangWenBin
:Description: 
"""

from seven_shop_studio.models.db_models.coupon.coupon_goods_model import *

class CouponGoodsModelEx(CouponGoodsModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)

    def get_coupon_goods_list(self, coupon_id):
        """
        :description: 获取优惠券商品列表
        :last_editors: KangWenBin
        """        
        sql = "select a.goods_short_name,a.goods_main_images as goods_picture,b.goods_id from goods_tb a join coupon_goods_tb b on a.id=b.goods_id where a.status = 1 and b.coupon_id=%s"
        params = [coupon_id]
        goods_list = self.db.fetch_all_rows(sql, params)
        # 处理商品图片
        for item in goods_list:
            try:
                item["goods_picture"] = json.loads(item["goods_picture"])[0]
            except:
                item["goods_picture"] = ""
        return goods_list


# -*- coding: utf-8 -*-
"""
:Author: Kangwenbin
:Date: 2022-11-21 17:46:56
:LastEditTime: 2024-06-19 14:43:24
:LastEditors: KangWenBin
:Description: 
"""
from seven_shop_studio.handlers.server.shop import *
from seven_shop_studio.handlers.server.category import *
from seven_shop_studio.handlers.server.series import *
from seven_shop_studio.handlers.server.order import *
from seven_shop_studio.handlers.server.goods import *
from seven_shop_studio.handlers.server.coupon import *


def seven_shop_studio_route():
    return [
        # 店铺
            (r"/server/shop/info", ShopInfoHandler), # 店铺信息

            # 分类
            (r"/server/category/info", CategoryInfoHandler), # 分类保存/分类上下架 
            (r"/server/category/list", CategoryListHandler), # 分类列表 
            
            # 系列
            (r"/server/series/info", SeriesInfoHandler), # 系列保存/系列上下架
            (r"/server/series/list", SeriesListHandler), # 系列列表 
            
            # 订单
            (r"/server/order/list", OrderListHandler), # 订单列表
            (r"/server/order/info", OrderInfoHandler), # 订单
            (r"/server/refund/list", RefundOrderListHandler), # 退款订单列表
            (r"/server/refund/info", RefundOrderInfoHandler), # 退款订单操作
            (r"/server/refund/notify", RefundNotifyHandler), # 微信退款回调

            # 商品
            (r"/server/goods/list", GoodsListHandler), # 商品列表
            (r"/server/goods/info", GoodsInfoHandler), # 商品信息
            (r"/server/goods/recommend", GoodsRecommendListHandler), # 推荐商品信息
            
            # 优惠券
            (r"/server/coupon/list", CouponListHandler), # 优惠券列表
            (r"/server/coupon/info", CouponInfoHandler), # 优惠券信息
            (r"/server/grant/list", CouponGrantListHandler), # 优惠券投放列表
            (r"/server/grant/info", CouponGrantInfoHandler), # 优惠券投放详情
    ]



# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2023-06-06 15:54:30
:LastEditTime: 2024-05-24 17:08:04
:LastEditors: KangWenBin
:Description: 
"""

# -*- coding: utf-8 -*-

from seven_studio.handlers.studio_base import *


class SevenBaseHandler(StudioBaseHandler):

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def write_error(self, status_code, **kwargs):
        """
        @description: 重写全局异常事件捕捉
        @last_editors: Kangwenbin
        """
        self.logger_error.error(traceback.format_exc())
        return self.reponse_json_error("server error")
    
    def load_json_or_empty(self,data):
        try:
            return json.loads(data)
        except:
            return []
    
    def param_check(self,param,check_list):
        """
        :description: 检查参数完整
        :last_editors: KangWenBin
        """       
        result = True
        for item in check_list:
            if not param.get(item,None):
                if param.get(item,None) == 0:
                    continue
                return False
        return result
    
    def dict_to_entity(self,entity,dict_info):
        """
        :description: 字段转化实体
        :last_editors: KangWenBin
        """        
        field_list = entity.get_field_list()
        for item in field_list:
            if item in dict_info:
                setattr(entity,item,dict_info[item])
        return entity
    



from seven_shop_studio.models.db_models.order.order_goods_model import *
from seven_shop_studio.models.db_models.order.order_refund_goods_model import *
from seven_shop_studio.models.db_models.coupon.coupon_record_model import *

class CouponHelper(object):
    @classmethod
    def refund_coupon_check(self, coupon_id, order_id):
        """
        :description: 检测优惠券是否可退
        :last_editors: KangWenBin
        """        
        if coupon_id > 0:
            order_goods_count = OrderGoodsModel().get_total(where="order_id = %s", params=[order_id])
            order_refund_goods_count = OrderRefundGoodsModel().get_total(where="order_id = %s", params=[order_id])
            if order_goods_count == order_refund_goods_count:
                # 退还优惠券
                CouponRecordModel().update_table("order_id = '',use_time = 0,status = 0","id = %s",coupon_id)




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class CouponRecordModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(CouponRecordModel, self).__init__(CouponRecord, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class CouponRecord:

    def __init__(self):
        super(CouponRecord, self).__init__()
        self.id = 0  # 
        self.shop_id = 0  # 店铺id
        self.grant_id = 0  # 投放id
        self.coupon_id = 0  # 优惠券id
        self.coupon_info = ""  # 优惠券领取快照
        self.use_price = 0  # 使用条件金额
        self.goods_limit = 0  # 使用限制 0 关闭 1 开启
        self.goods_list = ""  # 商品列表
        self.begin_time = 0  # 有效时间开始
        self.end_time = 0  # 有效时间结束
        self.user_code = ""  # 用户标识
        self.order_id = ""  # 订单号
        self.add_time = 0  # 领取时间
        self.use_time = 0  # 使用时间
        self.coupon_source = 0  # 0 领取 1 投放 2 发放
        self.status = 0  # 0 未使用 1 已使用

    @classmethod
    def get_field_list(self):
        return ['id', 'shop_id', 'grant_id', 'coupon_id', 'coupon_info', 'use_price', 'goods_limit', 'goods_list', 'begin_time', 'end_time', 'user_code', 'order_id', 'add_time', 'use_time', 'coupon_source', 'status']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "coupon_record_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-05-17 17:33:38
:LastEditTime: 2024-05-17 17:33:54
:LastEditors: KangWenBin
:Description: 
"""
from seven_shop_studio.models.db_models.inventory.inventory_model import *
from seven_shop_studio.models.db_models.inventory.inventory_change_model import *


class InventoryModelEx(InventoryModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)

    def get_inventory(self,goods_id,sku_id):
        """
        :description: 获取库存数量
        :last_editors: KangWenBin
        """        
        inventory = 0
        inventory_model = self.get_dict(where="goods_id = %s and sku_id = %s",params=[goods_id,sku_id],field="inventory")
        if inventory_model:
            inventory = inventory_model["inventory"]
        return inventory
    

    def check_goods_inventory(self,goods_id,sku_id):
        """
        :description: 单个商品库存验证
        :last_editors: Kangwenbin
        """        
        inventory_model = self.get_dict(where="goods_id = %s and sku_id = %s",params=[goods_id,sku_id],field="inventory")
        sum_inventory_model = InventoryChangeModel().get_dict(where="goods_id = %s and sku_id = %s",params=[goods_id,sku_id],field="IFNULL(sum(change_inventory),0) as change_inventory")
        if not inventory_model or not sum_inventory_model:
            return
        if inventory_model["inventory"] != sum_inventory_model["change_inventory"]:
            self.update_table(update_sql="inventory = %s",where="goods_id = %s and sku_id = %s",params=[sum_inventory_model["change_inventory"],goods_id,sku_id])


# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-06-04 10:16:19
:LastEditTime: 2024-06-19 14:46:39
:LastEditors: KangWenBin
:Description: 
"""
from seven_shop_studio.models.db_models.order.order_refund_model import *

class OrderRefundModelEx(OrderRefundModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)
    
    def get_refund_order_page_list(self, page_index, page_size, where='', params=None):
        """
        :description: 退款订单列表
        :last_editors: KangWenBin
        """        
        limit = f"LIMIT {str(int(page_index) * int(page_size))},{str(page_size)}"

        condition = ""
        if where:
            condition += f" where {where}"


        sql = f"SELECT a.order_id,a.refund_order_id,a.add_time,IF(b.logistics_number = '',0,1) AS logistics_status,a.real_refund_price,a.refund_type,a.reason,a.status  FROM order_refund_tb a  JOIN order_tb b ON a.order_id = b.order_id JOIN order_refund_goods_tb c ON a.refund_order_id = c.refund_order_id {condition} GROUP BY a.refund_order_id ORDER BY a.add_time desc {limit}"

        ret_list = self.db.fetch_all_rows(sql,params)
        sql_count = f"SELECT COUNT(*) as order_count FROM (SELECT a.order_id FROM order_refund_tb a  JOIN order_tb b ON a.order_id = b.order_id JOIN order_refund_goods_tb c ON a.refund_order_id = c.refund_order_id {condition} GROUP BY a.refund_order_id) AS order_table "
        row = self.db.fetch_one_row(sql_count,params)
        
        return ret_list,row["order_count"]


# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-05-22 14:49:26
:LastEditTime: 2024-06-19 11:33:59
:LastEditors: KangWenBin
:Description: 
"""
from seven_framework.web_tornado.base_handler.base_api_handler import *
from seven_shop_studio.handlers.seven_base import SevenBaseHandler
from seven_shop_studio.models.db_models.order.order_model_ex import *
from seven_shop_studio.models.db_models.order.order_goods_models_ex import *
from seven_shop_studio.models.db_models.order.order_refund_model_ex import *
from seven_shop_studio.models.db_models.order.order_refund_goods_model import *
from seven_shop_studio.libs.customize.coupon_helper import *
from seven_shop_studio.libs.customize.wechat_helper import *

class OrderListHandler(SevenBaseHandler):
    @filter_check_params(["shop_id"])
    def get_async(self, *args, **kwargs):
        """
        :description: 订单列表
        :last_editors: KangWenBin
        """        
        page_index = int(self.request_params.get("page_index",0))
        page_size = int(self.request_params.get("page_size",10))
        sel_order_id = self.request_params.get("sel_order_id", None)
        sel_goods_name = self.request_params.get("sel_goods_name", None)
        sel_user_code = self.request_params.get("sel_user_code", None)
        sel_status = self.request_params.get("sel_status",None)
        sel_begin_time = self.request_params.get("sel_begin_time", None)
        sel_end_time = self.request_params.get("sel_end_time", None)
        shop_id = self.request_params["shop_id"]

        condition = "shop_id = %s"
        param_list = [shop_id]

        if sel_order_id:
            condition += " and a.order_id = %s"
            param_list.append(sel_order_id)

        if sel_goods_name:
            condition += " and b.goods_name like %s"
            param_list.append(f"%{sel_goods_name}%")

        if sel_user_code:
            condition += " and a.user_code = %s"
            param_list.append(sel_user_code)

        if sel_status:
            condition += " and a.status = %s"
            param_list.append(sel_status)

        if sel_begin_time:
            condition += " and a.add_time >= %s"
            param_list.append(sel_begin_time)

        if sel_end_time:
            condition += " and a.add_time <= %s"
            param_list.append(sel_end_time)

        
        order_list,order_count = OrderModelEx().get_order_page_list(page_index,page_size,condition,param_list)
        if order_list:
            # 获取订单对应的商品信息
            order_id_list = [x["order_id"] for x in order_list]
            # 订单商品列表
            order_goods_list = OrderGoodsModelEx().get_order_goods_list(order_id_list)

            for item in order_list:
                item["order_goods_list"] = [x for x in order_goods_list if x["order_id"] == item["order_id"]]
                

        ret_data = {
            "model_list": order_list,
            "count": order_count
        }

        return self.reponse_json_success(ret_data)
    

class OrderInfoHandler(SevenBaseHandler):
    @filter_check_params(["order_id","shop_id"])
    def get_async(self):
        """
        :description: 订单详情
        :last_editors: KangWenBin
        """        
        order_id = self.request_params["order_id"]
        shop_id = self.request_params["shop_id"]
        
        order_model = OrderModel().get_dict(where="order_id = %s and shop_id = %s",params=[order_id,shop_id],field="order_id,add_time,status,province_name,city_name,district_name,consignee,phone,address_info,logistics_company,logistics_number,pay_order_id,pay_time,price,real_pay_price,postage,coupon_price")
        if not order_model:
            return self.reponse_json_error("无法获取订单信息")

        order_goods_list = OrderGoodsModelEx().get_order_goods_list([order_id])
        order_model["goods_list"] = order_goods_list
        ret_data = {
            "order_info":order_model
        }
        return self.reponse_json_success(ret_data)
        

    @filter_check_params(["order_id","logistics_status","shop_id"])
    def post_async(self):
        """
        :description: 订单发货
        :last_editors: KangWenBin
        """        
        order_id = self.request_params["order_id"]
        logistics_status = self.request_params["logistics_status"] # 0 不予发货 1 发货 2 取消不予发货
        logistics_company = self.request_params.get("logistics_company",None)
        logistics_number = self.request_params.get("logistics_number",None)
        shop_id = self.request_params["shop_id"]

        order_conn = OrderModel()

        order_model = order_conn.get_dict(where="order_id = %s and shop_id = %s",params=[order_id,shop_id],field="status")
        if not order_model:
            return self.reponse_json_error("无法获取订单信息")
        
        if logistics_status in [0,1]:
            if order_model["status"] not in [2,3]:
                return self.reponse_json_error("订单状态异常")
            
            if logistics_status == 0:
                if order_conn.update_table("status = 5,logistics_time = %s","order_id = %s",[TimeHelper.get_now_timestamp(),order_id]):
                    return self.reponse_json_success(desc="提交成功")
            elif logistics_status == 1:
                if not logistics_company or not logistics_number:
                    return self.reponse_json_error("发货信息异常")
                
                if order_conn.update_table("status = 3,logistics_company=%s,logistics_number= %s,logistics_time = %s","order_id = %s",[logistics_company,logistics_number,TimeHelper.get_now_timestamp(),order_id]):
                    return self.reponse_json_success(desc="提交成功")
        
        elif logistics_status == 2:
            if order_model["status"] != 5:
                return self.reponse_json_error("订单状态异常")
            
            if order_conn.update_table("status = 2,logistics_time = 0","order_id = %s",[order_id]):
                    return self.reponse_json_success(desc="提交成功")
        
        else:
            return self.reponse_json_error("参数错误")
        
        self.reponse_json_error("提交失败")


    @filter_check_params(["remark","order_id","shop_id"])
    def put_async(self):
        """
        :description: 设置备注
        :last_editors: KangWenBin
        """        
        order_id = self.request_params["order_id"]
        shop_id = self.request_params["shop_id"]
        remark = self.request_params["remark"]

        if OrderModel().update_table("shop_remark = %s","order_id = %s and shop_id = %s",[remark,order_id,shop_id]):
            return self.reponse_json_success(desc="提交成功")
        
        self.reponse_json_error("提交失败")


class RefundOrderListHandler(SevenBaseHandler):
    @filter_check_params(["shop_id"])
    def get_async(self, *args, **kwargs):
        """
        :description: 订单列表
        :last_editors: KangWenBin
        """        
        page_index = int(self.request_params.get("page_index",0))
        page_size = int(self.request_params.get("page_size",10))
        sel_user_code = self.request_params.get("sel_user_code", None)
        sel_order_id = self.request_params.get("sel_order_id", None)
        sel_refund_order_id = self.request_params.get("sel_refund_order_id", None)
        sel_logistics_status = self.request_params.get("sel_logistics_status", None)
        sel_refund_type = self.request_params.get("sel_refund_type", None)
        sel_goods_name = self.request_params.get("sel_goods_name", None)
        sel_status = self.request_params.get("sel_status",None)
        sel_begin_time = self.request_params.get("sel_begin_time", None)
        sel_end_time = self.request_params.get("sel_end_time", None)
        shop_id = self.request_params["shop_id"]

        condition = "a.shop_id = %s"
        param_list = [shop_id]

        if sel_order_id:
            condition += " and a.order_id = %s"
            param_list.append(sel_order_id)

        if sel_user_code:
            condition += " and a.user_code = %s"
            param_list.append(sel_user_code)

        if sel_refund_order_id:
            condition += " and a.refund_order_id = %s"
            param_list.append(sel_refund_order_id)

        if sel_logistics_status:
            if sel_logistics_status == "0":
                condition += " and b.logistics_number = ''"
            else:
                condition += " and b.logistics_number != ''"
        
        if sel_refund_type:
            condition += " and a.refund_type = %s"
            param_list.append(sel_refund_type)

        if sel_goods_name:
            condition += " and b.goods_name like %s"
            param_list.append(f"%{sel_goods_name}%")

        if sel_status:
            condition += " and a.status = %s"
            param_list.append(sel_status)

        if sel_begin_time:
            condition += " and a.add_time >= %s"
            param_list.append(sel_begin_time)

        if sel_end_time:
            condition += " and a.add_time <= %s"
            param_list.append(sel_end_time)

        
        refund_order_list,refund_order_count = OrderRefundModelEx().get_refund_order_page_list(page_index,page_size,condition,param_list)
        if refund_order_list:
            # 获取订单对应的商品信息
            refund_order_id_list = [x["refund_order_id"] for x in refund_order_list]
            # 订单商品列表
            refund_order_goods_list = OrderRefundGoodsModel().get_dict_list(where="refund_order_id in %s",params=(refund_order_id_list,),field="refund_order_id,sku_name,goods_name,goods_picture,refund_count,refund_price")

            for item in refund_order_list:
                item["refund_order_goods_list"] = [x for x in refund_order_goods_list if x["refund_order_id"] == item["refund_order_id"]]
                

        ret_data = {
            "model_list": refund_order_list,
            "count": refund_order_count
        }

        return self.reponse_json_success(ret_data)
    

class RefundOrderInfoHandler(SevenBaseHandler):

    @filter_check_params(["refund_order_id","refund_status","shop_id"])
    def post_async(self):
        """
        :description: 退款/审核
        :last_editors: KangWenBin
        """        
        refund_order_id = self.request_params["refund_order_id"]
        refund_status = self.request_params["refund_status"] # 1 通过 2 拒绝
        remark = self.request_params.get("remark", "")
        shop_id = self.request_params["shop_id"]

        refund_conn = OrderRefundModelEx()
        refund_model = refund_conn.get_dict(where="refund_order_id = %s and shop_id = %s",params=[refund_order_id,shop_id],field="refund_type,status,order_id,real_refund_price")
        if not refund_model:
            return self.reponse_json_error("退款单不存在")
        
        refund_mark = 0 # 是否需要退款标识

        if refund_model["status"] == 0: # 审核
            if refund_conn.update_table("status = %s,pass_time = %s,pass_remark = %s","refund_order_id = %s",[refund_status,TimeHelper.get_now_timestamp(),remark,refund_order_id]):
                if refund_model["refund_type"] == 1 and refund_status == 1:
                    refund_mark = 1
                else:
                    return self.reponse_json_success(desc="提交成功")
                
        elif refund_model["status"] == 3:
            if refund_status == 1:
                refund_mark = 1

            else:
                # 拒绝
                if refund_conn.update_table("status = 2,pass_time = %s,pass_remark = %s","refund_order_id = %s",[TimeHelper.get_now_timestamp(),remark,refund_order_id]):
                    return self.reponse_json_success(desc="提交成功")
        
        else:
            return self.reponse_json_error("退款单状态异常")

        if refund_mark == 1:
            # 退款
            order_model = OrderModel().get_dict(where="order_id = %s",params=refund_model["order_id"],field="real_pay_price,coupon_id")
            if not order_model:
                return self.reponse_json_error("无法获取订单信息")
            
            # 判断退款金额和优惠券信息
            if refund_model["real_refund_price"]>0:
                # 通过(调用微信退款)
                refund_result = WechatPayHelper().wechat_jsapi_refund(order_id=refund_model["order_id"],refund_order_id=refund_order_id,refund_price=int(refund_model["real_refund_price"]*100),total_price=int(order_model["real_pay_price"]*100))
                if refund_result["result"] == 1:
                    # 退款成功(更新退款单状态)
                    if refund_conn.update_table("refund_status = 1,refund_pay_id = %s","refund_order_id = %s",[refund_result["data"]["refund_id"],refund_order_id]):
                        return self.reponse_json_success(desc="提交成功")
                    else:
                        return self.reponse_json_error("提交失败")
                else:
                    # 退款失败
                    self.logger_error.error(f"退款失败,退款单号:{refund_order_id},error_msg:{refund_result['desc']}")
                    refund_conn.update_table("refund_status = 3,refund_info = %s","refund_order_id = %s",[refund_result["desc"],refund_order_id])
                    return self.reponse_json_error(f"退款失败:{refund_result['desc']}")
            else:
                # 无需退款，直接更改退款单状态
                if refund_conn.update_table("status = 5,finish_time = %s","refund_order_id = %s",[TimeHelper.get_now_timestamp(),refund_order_id]):
                    # 验证优惠券是否需要回退
                    CouponHelper.refund_coupon_check(order_model["coupon_id"],refund_model["order_id"])
                    return self.reponse_json_success(desc="提交成功") 
                    
            
        self.reponse_json_error("提交失败")

    
class RefundNotifyHandler(SevenBaseHandler):
    def post_async(self):
        """
        @description: 微信退款回调
        @last_editors: KangWenBin
        """
        wechat_helper = WechatPayHelper()
        # 微信支付验签
        headers = self.request.headers._dict
        timestamp = headers.get("Wechatpay-Timestamp", None)
        nonce = headers.get("Wechatpay-Nonce", None)
        signature = headers.get("Wechatpay-Signature", None)

        data = self.request.body
        self.logger_info.info(f"timestamp:{timestamp},nonce:{nonce},signature:{signature},data:{data}")
        if wechat_helper.check_notify_sign(timestamp,nonce,data,signature):
            # 验签通过
            data = json.loads(data)
            
            # data解密
            pay_string =  wechat_helper.decode_notify_data(data["resource"]["ciphertext"],data["resource"]["nonce"],data["resource"]["original_type"])
            pay_data = json.loads(pay_string)

            refund_order_id = pay_data["out_refund_no"]
            refund_conn = OrderRefundModel()
            refund_model = refund_conn.get_dict(where="refund_order_id = %s",params = refund_order_id,field="status,real_refund_price,order_id")
            if not refund_model:
                self.logger_error.error(f"退款回调:无法获取退款单信息,refund_order_id:{refund_order_id}")
                return self.write("success")
            
            order_model = OrderModel().get_dict(where="order_id = %s",params = refund_model["order_id"],field="coupon_id")
            if not order_model:
                self.logger_error.error(f"退款回调:无法获取订单信息,order_id:{refund_model['order_id']}")
                return self.write("success")
            
            # 验证退款金额
            if int(refund_model["real_refund_price"]*100) != pay_data["amount"]["refund"]:
                self.logger_error.error(
                    f"微信退款订单[{refund_order_id}] 金额不匹配.数据库金额:{refund_model['real_refund_price']*100} 平台回调金额:{pay_data['amount']['refund']};")
                return self.write("error")

            if pay_data["trade_state"] != "SUCCESS": # 退款成功
                # 修改退款单状态
                if refund_conn.update_table(update_sql="status = 5,refund_status = 2,refund_info = %s,finish_time = %s",where="refund_order_id = %s",params = [data["summary"],TimeHelper.get_now_timestamp(),refund_order_id]):
                    # 验证优惠券是否需要回退
                    CouponHelper.refund_coupon_check(order_model["coupon_id"],refund_model["order_id"])
                    return self.write("success")
            else:
                # 退款失败
                if refund_conn.update_table(update_sql="status = 6,refund_status = 3,refund_info = %s,finish_time = %s",where="refund_order_id = %s",params = [data["summary"],TimeHelper.get_now_timestamp(),refund_order_id]):
                    return self.write("success")

        else:
            self.logger_error.error(f"微信验签失败,data:{data}")
            return self.write("success")
        

        self.write("success")


# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-05-23 16:15:15
:LastEditTime: 2024-06-18 15:20:46
:LastEditors: KangWenBin
:Description: 
"""
from seven_framework.web_tornado.base_handler.base_api_handler import *
from seven_shop_studio.handlers.seven_base import SevenBaseHandler
from seven_shop_studio.models.db_models.coupon.coupon_model import *
from seven_shop_studio.models.db_models.coupon.coupon_goods_model_ex import *
from seven_shop_studio.models.db_models.coupon.coupon_record_model import *
from seven_shop_studio.models.db_models.coupon.coupon_grant_model_ex import *

class CouponListHandler(SevenBaseHandler):
    @filter_check_params(["shop_id"])
    def get_async(self, *args, **kwargs):
        """
        :description: 优惠券列表
        :last_editors: KangWenBin
        """        
        page_index = int(self.request_params.get("page_index",0))
        page_size = int(self.request_params.get("page_size",10))
        sel_coupon_name = self.request_params.get("sel_coupon_name", None)
        sel_status = self.request_params.get("sel_status", None)
        sel_coupon_type = self.request_params.get("sel_coupon_type", None)
        shop_id = self.request_params["shop_id"]
        
        condition = "status > -1 and shop_id = %s"
        param_list = [shop_id]
        
        if sel_coupon_name:
            condition += " and coupon_name like %s"
            param_list.append(f"%{sel_coupon_name}%")

        if sel_status:
            condition += " and status = %s"
            param_list.append(sel_status)

        if sel_coupon_type:
            condition += " and coupon_type = %s"
            param_list.append(sel_coupon_type)

        coupon_conn = CouponModel()
        
        coupon_list,coupon_count = coupon_conn.get_dict_page_list(field="id,coupon_name,coupon_type,use_price,coupon_price,coupon_discount,coupon_inventory,record_number,begin_time,end_time,status,add_time,is_receive", page_index=page_index,page_size=page_size,order_by="id desc",where=condition,params=param_list)
        if coupon_list:
            record_conn = CouponRecordModel()
            # 获取已使用量
            coupon_ids = [item["id"] for item in coupon_list]
            record_list = record_conn.get_dict_list(field="coupon_id,count(id) as used_count", where="coupon_id in %s and status = 1",params=(coupon_ids,), group_by="coupon_id")
            for item in coupon_list:
                item["used_number"] = 0
                record_model = [x for x in record_list if x["coupon_id"] == item["id"]]
                if record_model:
                    item["used_number"] = record_model[0]["used_count"]
                item["last_number"] = item["coupon_inventory"] - item["record_number"]

        ret_data = {
            "model_list": coupon_list,
            "count": coupon_count
        }

        return self.reponse_json_success(ret_data)


class CouponInfoHandler(SevenBaseHandler):
    @filter_check_params(["coupon_id","shop_id"])
    def get_async(self):
        """
        :description: 获取优惠券信息
        :last_editors: KangWenBin
        """        
        coupon_id = self.request_params["coupon_id"]
        shop_id = self.request_params["shop_id"]
        
        coupon_model = CouponModel().get_dict(where="id = %s and shop_id = %s", params=[coupon_id,shop_id],field="id,coupon_name,coupon_type,coupon_price,coupon_discount,use_price,coupon_inventory,begin_time,end_time,goods_limit,using_rule,is_receive")
        if not coupon_model:
            return self.reponse_json_error("获取优惠券信息失败")
        
        coupon_model["goods_list"] = CouponGoodsModelEx().get_coupon_goods_list(coupon_id)
        
        return self.reponse_json_success(coupon_model)


    @filter_check_params(["coupon_info","shop_id"])
    def post_async(self, *args, **kwargs):
        """
        :description: 优惠券保存
        :last_editors: rigger
        """
        coupon_info = self.request_params["coupon_info"]
        goods_list = self.request_params.get("goods_list")
        shop_id = self.request_params["shop_id"]

        coupon_conn = CouponModel()
        # 参数验证
        coupon_check_list = ["id","coupon_name","coupon_type","goods_limit",
                      "use_price","coupon_inventory","begin_time","end_time","using_rule"]
        if not self.param_check(coupon_info, coupon_check_list):
            return self.reponse_json_error("优惠券表单未填写完整")
        
        # 判断优惠券金额
        if coupon_info["use_price"] > 0 and coupon_info["coupon_type"] == 0 and coupon_info["coupon_price"] > coupon_info["use_price"]:
            return self.reponse_json_error("优惠券金额必须小于使用金额")

        # 验证优惠券限制商品
        if coupon_info["goods_limit"] == 1 and not goods_list:
            return self.reponse_json_error("请选择限制商品")
        
        # 验证优惠券类型
        if coupon_info["coupon_type"] == 0 and coupon_info["coupon_price"] <= 0:
            return self.reponse_json_error("优惠券金额必须大于0")
        
        if coupon_info["coupon_type"] == 1 and coupon_info["coupon_discount"] <= 0:
            return self.reponse_json_error("优惠券折扣必须大于0")

        coupon_entity = self.dict_to_entity(Coupon(), coupon_info)
        
        if coupon_entity.id > 0:
            # 修改
            old_coupon_model = coupon_conn.get_entity_by_id(coupon_entity.id)
            if not old_coupon_model:
                return self.reponse_json_error("优惠券不存在")
            if old_coupon_model.status == 1:
                return self.reponse_json_error("优惠券已发布，无法修改")
            
            # 验证优惠券库存只能增加，不能减少
            if old_coupon_model.coupon_inventory > coupon_entity.coupon_inventory:
                return self.reponse_json_error("优惠券库存只能增加，不能减少")
            
            coupon_entity.add_time = old_coupon_model.add_time
            coupon_entity.status = old_coupon_model.status
            coupon_entity.shop_id = old_coupon_model.shop_id
            coupon_conn.update_entity(coupon_entity)
            # 删除原来关联商品
            coupon_goods_conn = CouponGoodsModel()
            coupon_goods_conn.del_entity(where="coupon_id = %s",params=[coupon_entity.id])
            if coupon_info["goods_limit"] == 1:
                # 添加限制商品
                for goods_id in goods_list:
                    coupon_goods_entity = CouponGoods()
                    coupon_goods_entity.coupon_id = coupon_entity.id
                    coupon_goods_entity.goods_id = goods_id
                    coupon_goods_conn.add_entity(coupon_goods_entity)
            return self.reponse_json_success(desc="提交成功")
                
        else:
            # 新增
            coupon_entity.add_time = TimeHelper.get_now_timestamp()
            coupon_entity.shop_id = shop_id
            coupon_entity.status = 0
            result = coupon_conn.add_entity(coupon_entity)
            if result > 0:
                if coupon_info["goods_limit"] == 1:
                    # 添加限制商品
                    coupon_goods_conn = CouponGoodsModel()
                    for goods_id in goods_list:
                        coupon_goods_entity = CouponGoods()
                        coupon_goods_entity.coupon_id = result
                        coupon_goods_entity.goods_id = goods_id
                        coupon_goods_conn.add_entity(coupon_goods_entity)
                return self.reponse_json_success(desc="提交成功")
            
        
        self.reponse_json_error("提交失败")
        

    @filter_check_params(["coupon_id","shop_id"])
    def put_async(self, *args, **kwargs):
        """
        :description: 优惠券上下架
        :last_editors: rigger
        """
        # 优惠券id
        coupon_id = self.request_params["coupon_id"]
        # 店铺id
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        coupon_conn = CouponModel()
        
        coupon_info = coupon_conn.get_dict(where="id = %s and shop_id = %s",params=[coupon_id,shop_id],field="status")
        if not coupon_info or coupon_info["status"] == -1:
            return self.reponse_json_error("无法获取优惠券信息")

        status = 0
        if coupon_info["status"] == 0:
            status = 1
        
        if status == 0:
            # 判断优惠券是否在投放计划中
            grant_model = CouponGrantModel().get_dict(where="coupon_id = %s and status = 1",params=[coupon_id],field="id")
            if grant_model:
                return self.reponse_json_error("该优惠券所绑定投放计划进行中，无法下架")

        if coupon_conn.update_table("status = %s","id = %s",[status,coupon_id]):
            return self.reponse_json_success(desc="提交成功")
        
        self.reponse_json_error("提交失败")
        

    @filter_check_params(["coupon_id","shop_id"])
    def delete_async(self, *args, **kwargs):
        """
        :description: 优惠券删除
        :last_editors: rigger
        """
        # 优惠券id
        coupon_id = self.request_params["coupon_id"]
        # 店铺id
        shop_id = self.request_params["shop_id"]
        
        # TODO 执行业务
        coupon_conn = CouponModel()
        
        coupon_info = coupon_conn.get_dict(where="id = %s and shop_id = %s",params=[coupon_id,shop_id],field="status")
        if not coupon_info or coupon_info["status"] == -1:
            return self.reponse_json_error("无法获取优惠券信息")
        
        if coupon_info["status"] == 1:
            return self.reponse_json_error("该优惠券已发布，无法删除")
        
        # 判断优惠券是否在投放计划中
        grant_model = CouponGrantModel.get_dict(where="coupon_id = %s and status = 1",params=[coupon_id],field="id")
        if grant_model:
            return self.reponse_json_error("该优惠券所绑定投放计划进行中，无法删除")
        
        if coupon_conn.update_table("status = -1","id = %s",coupon_id):
            return self.reponse_json_success(desc="提交成功")
        
        self.reponse_json_error("提交失败")


class CouponGrantListHandler(SevenBaseHandler):
    @filter_check_params(["shop_id"])
    def get_async(self, *args, **kwargs):
        """
        :description: 优惠券投放列表
        :last_editors: KangWenBin
        """        
        page_index = int(self.request_params.get("page_index",0))
        page_size = int(self.request_params.get("page_size",10))
        sel_grant_name = self.request_params.get("sel_grant_name", None)
        sel_grant_type = self.request_params.get("sel_grant_type", None)
        sel_status = self.request_params.get("sel_status", None)
        shop_id = self.request_params["shop_id"]
        
        condition = "a.status > -1 and b.shop_id = %s"
        param_list = [shop_id]

        if sel_status:
            condition += " and a.status = %s"
            param_list.append(sel_status)

        if sel_grant_name:
            condition += " and a.grant_name like %s"
            param_list.append(f"%{sel_grant_name}%")

        if sel_grant_type:
            condition += " and a.grant_type = %s"
            param_list.append(sel_grant_type)

        grant_list, grant_count = CouponGrantModelEx().get_grant_list(page_index,page_size,condition,param_list)
        if grant_list:
            # 获取已投放数量
            for grant_info in grant_list:
                grant_info["grant_type"] = json.loads(grant_info["grant_type"])
                grant_info["grant_count"] = CouponRecordModel().get_total(where="grant_id = %s",params= grant_info["id"])

        ret_data = {
            "model_list": grant_list,
            "count": grant_count,
            "coupon_list": CouponModel().get_dict_list(where="status >-1 and shop_id = %s",params=shop_id,field="id,coupon_name",order_by="id desc")
        }

        return self.reponse_json_success(ret_data)
    

class CouponGrantInfoHandler(SevenBaseHandler):
    @filter_check_params(["grant_id","shop_id"])
    def get_async(self):
        """
        :description: 获取投放信息
        :last_editors: KangWenBin
        """        
        grant_id = self.request_params["grant_id"]
        shop_id = self.request_params["shop_id"]

        grant_model = CouponGrantModel().get_dict_by_id(grant_id,field="id,grant_name,grant_type,coupon_id,begin_time,end_time,grant_picture")
        if not grant_model:
            return self.reponse_json_error("获取投放信息失败")
        
        coupon_model = CouponModel().get_dict(where="id = %s and shop_id = %s",params=[grant_model["coupon_id"],shop_id] ,field="status")
        if not coupon_model:
            return self.reponse_json_error("获取投放信息归属失败")
        
        grant_model["grant_type"] = json.loads(grant_model["grant_type"])
        self.reponse_json_success(grant_model)


    @filter_check_params(["grant_info","shop_id"])
    def post_async(self, *args, **kwargs):
        """
        :description: 投放保存
        :last_editors: rigger
        """
        grant_info = self.request_params["grant_info"]
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        grant_conn = CouponGrantModel()
        
        # 参数验证
        field_check_list = ["id","grant_name","coupon_id","begin_time",
                      "end_time","grant_type","grant_picture"]
        if not self.param_check(grant_info, field_check_list):
            return self.reponse_json_error("投放表单未填写完整")
        
        # 验证优惠券信息
        coupon_model = CouponModel().get_dict(where="id = %s and shop_id = %s",params=[grant_info["coupon_id"],shop_id] ,field="status")
        if not coupon_model:
            return self.reponse_json_error("优惠券不存在")

        grant_entity = self.dict_to_entity(CouponGrant(), grant_info)
        
        if grant_entity.id > 0:
            # 修改
            old_grant_model = grant_conn.get_entity_by_id(grant_entity.id)
            if not old_grant_model:
                return self.reponse_json_error("投放计划不存在")
            
            if old_grant_model.status == 1:
                return self.reponse_json_error("投放计划已发布，无法修改")
            grant_entity.grant_type = json.dumps(grant_entity.grant_type)
            grant_entity.add_time = old_grant_model.add_time
            grant_entity.status = old_grant_model.status
            grant_conn.update_entity(grant_entity)

            return self.reponse_json_success(desc="提交成功")
                
        else:
            # 新增
            grant_entity.add_time = TimeHelper.get_now_timestamp()
            grant_entity.status = 0
            grant_entity.grant_type = json.dumps(grant_entity.grant_type)
            result = grant_conn.add_entity(grant_entity)
            if result > 0:
                return self.reponse_json_success(desc="提交成功")
            
        
        self.reponse_json_error("提交失败")
        

    @filter_check_params(["grant_id","shop_id"])
    def put_async(self, *args, **kwargs):
        """
        :description: 投放上下架
        :last_editors: rigger
        """
        # 分类id 
        grant_id = self.request_params["grant_id"]
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        conn = CouponGrantModel()
        grant_model = conn.get_dict_by_id(grant_id,field="status,coupon_id")
        if not grant_model or grant_model["status"] == -1:
            return self.reponse_json_error("无法获取投放信息")
        
        # 获取优惠券信息
        coupon_model = CouponModel().get_dict(where="id = %s and shop_id = %s",params=[grant_model["coupon_id"],shop_id] ,field="status")
        if not coupon_model or coupon_model["status"] == -1:
            return self.reponse_json_error("无法获取优惠券信息")
        
        status = 0
        if grant_model["status"] == 0:
            status = 1

        if status == 1 and coupon_model["status"]!=1:
            return self.reponse_json_error("该计划所绑定优惠券下架/删除，无法发布")

        if conn.update_table("status = %s","id = %s",[status,grant_id]):
            return self.reponse_json_success(desc="提交成功")
        
        self.reponse_json_error("提交失败")
        

    @filter_check_params(["grant_id","shop_id"])
    def delete_async(self, *args, **kwargs):
        """
        :description: 投放删除
        :last_editors: rigger
        """
        # 分类id 
        grant_id = self.request_params["grant_id"]
        shop_id = self.request_params["shop_id"]

        # TODO 执行业务
        conn = CouponGrantModel()
        grant_model = conn.get_dict_by_id(grant_id,field="status,coupon_id")
        if not grant_model or grant_model["status"] == -1:
            return self.reponse_json_error("无法获取投放信息")
        
        # 获取优惠券信息
        coupon_model = CouponModel().get_dict(where="id = %s and shop_id = %s",params=[grant_model["coupon_id"],shop_id] ,field="status")
        if not coupon_model:
            return self.reponse_json_error("投放信息异常")

        if grant_model["status"] == 1:
            return self.reponse_json_error("投放中无法删除")

        if conn.update_table("status = -1","id = %s",grant_id):
            return self.reponse_json_success(desc = "提交成功")
        
        self.reponse_json_error("提交失败")
    

# class CouponUserListHandler(SevenBaseHandler):



from seven_shop_studio.models.db_models.order.order_model import *


class OrderModelEx(OrderModel):
    
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)

    def get_order_page_list(self, page_index, page_size, where='', params=None):
        """
        :description: 订单列表
        :last_editors: KangWenBin
        """        
        limit = f"LIMIT {str(int(page_index) * int(page_size))},{str(page_size)}"

        condition = ""
        if where:
            condition += f" where {where}"


        sql = f"SELECT a.order_id,a.add_time,a.real_pay_price,a.remark,a.shop_remark,a.status,a.province_name,a.city_name,a.district_name,a.consignee,a.phone,a.address_info,a.logistics_company,a.logistics_number FROM order_tb a left JOIN order_goods_tb b ON a.order_id = b.order_id {condition} group by a.order_id order by a.add_time desc {limit}"

        ret_list = self.db.fetch_all_rows(sql,params)
        sql_count = f"SELECT COUNT(*) as order_count FROM (SELECT a.order_id FROM order_tb a LEFT JOIN order_goods_tb b ON a.order_id = b.order_id {condition} GROUP BY a.order_id) AS order_table "
        row = self.db.fetch_one_row(sql_count,params)
        
        return ret_list,row["order_count"]


# -*- coding: utf-8 -*-
"""
:Author: KangWenBin
:Date: 2024-05-27 15:36:11
:LastEditTime: 2024-06-19 14:46:05
:LastEditors: KangWenBin
:Description: 
"""
from seven_shop_studio.models.db_models.coupon.coupon_grant_model import *

class CouponGrantModelEx(CouponGrantModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)

    def get_grant_list(self, page_index, page_size, where='', params=None):
        """
        :description: 投放列表
        :last_editors: KangWenBin
        """        
        limit = f"LIMIT {str(int(page_index) * int(page_size))},{str(page_size)}"

        condition = ""
        if where:
            condition += f" where {where}"

        sql = f"SELECT a.id,a.grant_name,a.grant_type,a.grant_picture,a.begin_time,a.end_time,a.status AS grant_status,a.add_time,b.coupon_name,b.status AS coupon_status,b.coupon_type FROM coupon_grant_tb a LEFT JOIN coupon_tb b ON a.coupon_id = b.id {condition} ORDER BY id desc {limit}"

        ret_list = self.db.fetch_all_rows(sql,params)
        sql_count = f"SELECT count(*) as count FROM coupon_grant_tb a LEFT JOIN coupon_tb b ON a.coupon_id = b.id {condition} " 
        row = self.db.fetch_one_row(sql_count,params)
        return ret_list,row["count"]
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class GoodsSkuModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(GoodsSkuModel, self).__init__(GoodsSku, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class GoodsSku:

    def __init__(self):
        super(GoodsSku, self).__init__()
        self.id = 0  # 
        self.goods_id = 0  # 商品id
        self.sku_name = ""  # sku组合名称
        self.sku_picture = ""  # sku图片
        self.sku_info = ""  # sku信息
        self.original_price = 0  # 划线价
        self.price = 0  # 价格
        self.integral = 0  # 积分
        self.goods_code = ""  # 商家编码
        self.add_time = 0  # 创建时间
        self.status = 0  # 1 正常 0 伪删除

    @classmethod
    def get_field_list(self):
        return ['id', 'goods_id', 'sku_name', 'sku_picture', 'sku_info', 'original_price', 'price', 'integral', 'goods_code', 'add_time', 'status']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "goods_sku_tb"
    


from seven_shop_studio.models.db_models.shop.shop_series_model import *

class ShopSeriesModelEx(ShopSeriesModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)
    
    def get_category_series_count(self,category_id):
        """
        :description: 获取分类对应系列数量
        :last_editors: KangWenBin
        """        
        sql = "select count(*) as goods_count from shop_category_series_tb a join shop_series_tb b on a.series_id = b.id where b.status>-1 and a.category_id = %s"
        return self.db.fetch_one_row(sql,category_id)["goods_count"]
    
    def get_series_category_list(self,series_id):
        """
        :description: 获取系列对应分类
        :last_editors: KangWenBin
        """        
        sql = "SELECT b.id,b.category_name FROM shop_category_series_tb a JOIN shop_category_tb b ON a.category_id = b.id WHERE a.series_id = %s AND b.status>-1"
        return self.db.fetch_all_rows(sql,series_id)



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class OrderRefundGoodsModel(BaseModel):
    def __init__(self, db_connect_key='db_shopping_center', sub_table=None, db_transaction=None, context=None):
        super(OrderRefundGoodsModel, self).__init__(OrderRefundGoods, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class OrderRefundGoods:

    def __init__(self):
        super(OrderRefundGoods, self).__init__()
        self.id = 0  # 
        self.order_id = ""  # 关联下单号
        self.refund_order_id = ""  # 关联退款单号
        self.goods_id = 0  # 商品id
        self.sku_id = 0  # sku_id
        self.sku_name = ""  # sku名称
        self.goods_name = ""  # 商品名称
        self.goods_picture = ""  # 商品图片
        self.refund_count = 0  # 退款数量
        self.refund_price = 0  # 退款金额
        self.add_time = 0  # 创建时间
        self.goods_code = ""  # 商家编码

    @classmethod
    def get_field_list(self):
        return ['id', 'order_id', 'refund_order_id', 'goods_id', 'sku_id', 'sku_name', 'goods_name', 'goods_picture', 'refund_count', 'refund_price', 'add_time', 'goods_code']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "order_refund_goods_tb"
    